@@ -21,36 +21,6 @@ SMBAuthenticator::SMBAuthenticator(SMBAbstractFrontend &frontend)
 {
 }
 
-void SMBAuthenticator::loadConfiguration()
-{
-// NOTE: the entire configuration group (or rather: it's KCM) is bound to go away in KF6.
-#if (QT_VERSION < QT_VERSION_CHECK(6, 0, 0))
-    KConfig cfg("kioslaverc", KConfig::NoGlobals);
-    const KConfigGroup group = cfg.group("Browser Settings/SMBro");
-    m_defaultUser = group.readEntry("User");
-    //  m_default_workgroup=group.readEntry("Workgroup");
-    //  m_showHiddenShares=group.readEntry("ShowHiddenShares", QVariant(false)).toBool();
-
-    QString m_encoding = QTextCodec::codecForLocale()->name();
-    m_defaultEncoding = group.readEntry("Encoding", m_encoding.toLower());
-
-    // unscramble, taken from Nicola Brodu's smb ioworker
-    // not really secure, but better than storing the plain password
-    QString scrambled = group.readEntry("Password");
-    m_defaultPassword = "";
-    for (int i = 0; i < scrambled.length() / 3; i++) {
-        QChar qc1 = scrambled[i * 3];
-        QChar qc2 = scrambled[i * 3 + 1];
-        QChar qc3 = scrambled[i * 3 + 2];
-        unsigned int a1 = qc1.toLatin1() - '0';
-        unsigned int a2 = qc2.toLatin1() - 'A';
-        unsigned int a3 = qc3.toLatin1() - '0';
-        unsigned int num = ((a1 & 0x3F) << 10) | ((a2 & 0x1F) << 5) | (a3 & 0x1F);
-        m_defaultPassword[i] = QChar((uchar)((num - 17) ^ 173)); // restore
-    }
-#endif
-}
-
 QString SMBAuthenticator::defaultWorkgroup() const
 {
     return m_defaultWorkgroup;
@@ -61,7 +31,15 @@ void SMBAuthenticator::setDefaultWorkgroup(const QString &workGroup)
     m_defaultWorkgroup = workGroup;
 }
 
-void SMBAuthenticator::auth(SMBCCTX *context, const char *server, const char *share, char *workgroup, int wgmaxlen, char *username, int unmaxlen, char *password, int pwmaxlen)
+void SMBAuthenticator::auth(SMBCCTX *context,
+                            const char *server,
+                            const char *share,
+                            char *workgroup,
+                            int wgmaxlen,
+                            char *username,
+                            int unmaxlen,
+                            char *password,
+                            int pwmaxlen)
 {
     qCDebug(KIO_SMB_LOG) << "auth_smbc_get_dat: set user=" << username << ", workgroup=" << workgroup << " server=" << server << ", share=" << share;
 
